summaryrefslogtreecommitdiff
path: root/pym
diff options
context:
space:
mode:
Diffstat (limited to 'pym')
-rw-r--r--pym/gentoolkit/enalyze/__init__.py (renamed from pym/gentoolkit/analyse/__init__.py)10
-rw-r--r--pym/gentoolkit/enalyze/analyze.py (renamed from pym/gentoolkit/analyse/analyse.py)46
-rw-r--r--pym/gentoolkit/enalyze/base.py (renamed from pym/gentoolkit/analyse/base.py)4
-rw-r--r--pym/gentoolkit/enalyze/lib.py (renamed from pym/gentoolkit/analyse/lib.py)4
-rw-r--r--pym/gentoolkit/enalyze/output.py (renamed from pym/gentoolkit/analyse/output.py)2
-rw-r--r--pym/gentoolkit/enalyze/rebuild.py (renamed from pym/gentoolkit/analyse/rebuild.py)26
6 files changed, 46 insertions, 46 deletions
diff --git a/pym/gentoolkit/analyse/__init__.py b/pym/gentoolkit/enalyze/__init__.py
index 46d6185..b43a82c 100644
--- a/pym/gentoolkit/analyse/__init__.py
+++ b/pym/gentoolkit/enalyze/__init__.py
@@ -16,7 +16,7 @@
__docformat__ = 'epytext'
# version is dynamically set by distutils sdist
__version__ = "svn"
-__productname__ = "analyse"
+__productname__ = "enalyze"
__authors__ = (
'Brian Dolbec, <brian.dolbec@gmail.com>'
@@ -48,15 +48,15 @@ from gentoolkit.formatters import format_options
NAME_MAP = {
- 'a': 'analyse',
+ 'a': 'analyze',
'r': 'rebuild'
}
FORMATTED_OPTIONS = (
- (" (a)nalyse",
- "analyses the installed PKG database USE flag or keyword useage"),
+ (" (a)nalyze",
+ "analyzes the installed PKG database USE flag or keyword useage"),
(" (r)ebuild",
- "analyses the Installed PKG database and generates files suitable"),
+ "analyzes the Installed PKG database and generates files suitable"),
(" ",
"to replace corrupted or missing /etc/portage/package.* files")
)
diff --git a/pym/gentoolkit/analyse/base.py b/pym/gentoolkit/enalyze/base.py
index a3f3fed..6622704 100644
--- a/pym/gentoolkit/analyse/base.py
+++ b/pym/gentoolkit/enalyze/base.py
@@ -6,7 +6,7 @@
#
# $Header: $
-"""Analyse Base Module class to hold common module operation functions
+"""Enalyze Base Module class to hold common module operation functions
"""
from __future__ import print_function
@@ -25,7 +25,7 @@ from gentoolkit.base import mod_usage
from gentoolkit import CONFIG
class ModuleBase(object):
- """Analyse base module class to parse module options print module help, etc.."""
+ """Enalyze base module class to parse module options print module help, etc.."""
def __init__(self):
self.module_name = None
diff --git a/pym/gentoolkit/analyse/lib.py b/pym/gentoolkit/enalyze/lib.py
index 901d757..015e23b 100644
--- a/pym/gentoolkit/analyse/lib.py
+++ b/pym/gentoolkit/enalyze/lib.py
@@ -6,7 +6,7 @@
#
-"""Provides support functions to analyse modules"""
+"""Provides support functions to enalyze modules"""
import sys
@@ -69,7 +69,7 @@ class FlagAnalyzer(object):
return self._analyse(installed, iuse)
def _analyse(self, installed, iuse):
- """Analyses the supplied info and returns the flag settings
+ """Analyzes the supplied info and returns the flag settings
that differ from the defaults
@type installed: set
diff --git a/pym/gentoolkit/analyse/output.py b/pym/gentoolkit/enalyze/output.py
index b193d54..326ebbc 100644
--- a/pym/gentoolkit/analyse/output.py
+++ b/pym/gentoolkit/enalyze/output.py
@@ -291,7 +291,7 @@ class RebuildPrinter(CpvValueWrapper):
h=("# This package.%s file was generated by "
%self.target +
- "gentoolkit's 'analyse rebuild' module\n"
+ "gentoolkit's 'enalyze rebuild' module\n"
"# Date: " + time.asctime() + "\n"
)
return h
diff --git a/pym/gentoolkit/analyse/analyse.py b/pym/gentoolkit/enalyze/analyze.py
index e2628e3..180865d 100644
--- a/pym/gentoolkit/analyse/analyse.py
+++ b/pym/gentoolkit/enalyze/analyze.py
@@ -14,11 +14,11 @@ import sys
import gentoolkit
from gentoolkit.dbapi import PORTDB, VARDB
-from gentoolkit.analyse.base import ModuleBase
+from gentoolkit.enalyze.base import ModuleBase
from gentoolkit import pprinter as pp
from gentoolkit.flag import get_installed_use, get_flags
-from gentoolkit.analyse.lib import FlagAnalyzer, KeywordAnalyser
-from gentoolkit.analyse.output import nl, AnalysisPrinter
+from gentoolkit.enalyze.lib import FlagAnalyzer, KeywordAnalyser
+from gentoolkit.enalyze.output import nl, AnalysisPrinter
from gentoolkit.package import Package
from gentoolkit.helpers import get_installed_cpvs
@@ -35,10 +35,10 @@ def gather_flags_info(
_get_flags=get_flags,
_get_used=get_installed_use
):
"""Analyse the installed pkgs USE flags for frequency of use
@type cpvs: list
- @param cpvs: optional list of [cat/pkg-ver,...] to analyse or
+ @param cpvs: optional list of [cat/pkg-ver,...] to analyze or
defaults to entire installed pkg db
@type: system_flags: list
@param system_flags: the current default USE flags as defined
@@ -46,13 +46,13 @@ def gather_flags_info(
@type include_unset: bool
@param include_unset: controls the inclusion of unset USE flags in the report.
@type target: string
- @param target: the environment variable being analysed
+ @param target: the environment variable being analyzed
one of ["USE", "PKGUSE"]
@type _get_flags: function
@param _get_flags: ovride-able for testing,
- defaults to gentoolkit.analyse.lib.get_flags
+ defaults to gentoolkit.enalyze.lib.get_flags
@param _get_used: ovride-able for testing,
- defaults to gentoolkit.analyse.lib.get_installed_use
+ defaults to gentoolkit.enalyze.lib.get_installed_use
@rtype dict. {flag:{"+":[cat/pkg-ver,...], "-":[cat/pkg-ver,...], "unset":[]}
"""
if cpvs is None:
@@ -103,9 +103,9 @@ def gather_keywords_info(
keywords=portage.settings["ACCEPT_KEYWORDS"],
analyser = None
):
- """Analyse the installed pkgs 'keywords' for frequency of use
+ """Analyze the installed pkgs 'keywords' for frequency of use
- @param cpvs: optional list of [cat/pkg-ver,...] to analyse or
+ @param cpvs: optional list of [cat/pkg-ver,...] to analyze or
defaults to entire installed pkg db
@param system_keywords: list of the system keywords
@param keywords: user defined list of keywords to check and report on
@@ -166,7 +166,7 @@ class Analyse(ModuleBase):
"""
def __init__(self):
ModuleBase.__init__(self)
- self.module_name = "analyse"
+ self.module_name = "enalyze"
self.options = {
"flags": False,
"keywords": False,
@@ -193,14 +193,14 @@ class Analyse(ModuleBase):
}
self.formatted_options = [
(" -h, --help", "Outputs this useage message"),
- (" -a, --analyse",
+ (" -a, --analyze",
"Action, sets the module to gather data and output the"),
("", "formatted stats/information to the screen"),
(" -u, --unset",
"Additionally include any unset USE flags and the packages"),
("", "that could use them"),
(" -v, --verbose",
- "Used in the analyse action to output more detailed information"),
+ "Used in the analyze action to output more detailed information"),
(" -p, --prefix",
"Used for testing purposes only, runs report using " +
"a prefix keyword and 'prefix' USE flag"),
@@ -210,15 +210,15 @@ class Analyse(ModuleBase):
]
self.formatted_args = [
(" use",
- "Causes the action to analyse the installed packages USE flags"),
+ "Causes the action to analyze the installed packages USE flags"),
(" pkguse",
- "Causes the action to analyse the installed packages PKGUSE flags"),
+ "Causes the action to analyze the installed packages PKGUSE flags"),
(" ",
"These are flags that have been set in /etc/portage/package.use"),
(" keywords",
- "Causes the action to analyse the installed packages keywords"),
+ "Causes the action to analyze the installed packages keywords"),
(" packages",
- "Causes the action to analyse the installed packages and the"),
+ "Causes the action to analyze the installed packages and the"),
(" ",
"USE flags they were installed with"),
]
@@ -251,12 +251,12 @@ class Analyse(ModuleBase):
self.analyse_packages()
def analyse_flags(self, target):
"""This will scan the installed packages db and analyse the
USE flags used for installation and produce a report on how
they were used.
@type target: string
- @param target: the target to be analysed, one of ["use", "pkguse"]
+ @param target: the target to be analyzed, one of ["use", "pkguse"]
"""
system_use = portage.settings["USE"].split()
self.printer = AnalysisPrinter(
@@ -307,7 +307,7 @@ class Analyse(ModuleBase):
def analyse_keywords(self, keywords=None):
"""This will scan the installed packages db and analyse the
keywords used for installation and produce a report on them.
"""
print()
@@ -390,11 +390,11 @@ class Analyse(ModuleBase):
def analyse_packages(self):
"""This will scan the installed packages db and analyse the
USE flags used for installation and produce a report.
@type target: string
- @param target: the target to be analysed, one of ["use", "pkguse"]
+ @param target: the target to be analyzed, one of ["use", "pkguse"]
"""
system_use = portage.settings["USE"].split()
if self.options["verbose"]:
@@ -437,7 +437,7 @@ class Analyse(ModuleBase):
def main(input_args):
"""Common starting method by the analyse master
unless all modules are converted to this class method.
@param input_args: input args as supplied by equery master module.
@@ -35,10 +35,10 @@ def gather_flags_info(
_get_used=get_installed_use
):
- """Analyse the installed pkgs USE flags for frequency of use
+ """Analyze the installed pkgs USE flags for frequency of use
@@ -251,12 +251,12 @@ class Analyse(ModuleBase):
self.analyse_packages()
def analyse_flags(self, target):
- """This will scan the installed packages db and analyse the
+ """This will scan the installed packages db and analyze the
USE flags used for installation and produce a report on how
they were used.
@@ -307,7 +307,7 @@ class Analyse(ModuleBase):
def analyse_keywords(self, keywords=None):
- """This will scan the installed packages db and analyse the
+ """This will scan the installed packages db and analyze the
keywords used for installation and produce a report on them.
"""
@@ -390,11 +390,11 @@ class Analyse(ModuleBase):
def analyse_packages(self):
- """This will scan the installed packages db and analyse the
+ """This will scan the installed packages db and analyze the
USE flags used for installation and produce a report.
@@ -437,7 +437,7 @@ class Analyse(ModuleBase):
def main(input_args):
- """Common starting method by the analyse master
+ """Common starting method by the analyze master
unless all modules are converted to this class method.
diff --git a/pym/gentoolkit/analyse/rebuild.py b/pym/gentoolkit/enalyze/rebuild.py
index 091df3a..f1d7e88 100644
--- a/pym/gentoolkit/analyse/rebuild.py
+++ b/pym/gentoolkit/enalyze/rebuild.py
@@ -18,12 +18,12 @@ import sys
import gentoolkit
from gentoolkit.dbapi import PORTDB, VARDB
-from gentoolkit.analyse.base import ModuleBase
+from gentoolkit.enalyze.base import ModuleBase
from gentoolkit import pprinter as pp
-from gentoolkit.analyse.lib import (get_installed_use, get_flags, FlagAnalyzer,
+from gentoolkit.enalyze.lib import (get_installed_use, get_flags, FlagAnalyzer,
KeywordAnalyser)
from gentoolkit.flag import reduce_flags
-from gentoolkit.analyse.output import RebuildPrinter
+from gentoolkit.enalyze.output import RebuildPrinter
from gentoolkit.atom import Atom
@@ -42,16 +42,16 @@ def cpv_all_diff_use(
and the currently installed pkgs recorded USE flag settings
@type cpvs: list
- @param cpvs: optional list of [cat/pkg-ver,...] to analyse or
+ @param cpvs: optional list of [cat/pkg-ver,...] to analyze or
defaults to entire installed pkg db
@type: system_flags: list
@param system_flags: the current default USE flags as defined
by portage.settings["USE"].split()
@type _get_flags: function
@param _get_flags: ovride-able for testing,
- defaults to gentoolkit.analyse.lib.get_flags
+ defaults to gentoolkit.enalyze.lib.get_flags
@param _get_used: ovride-able for testing,
- defaults to gentoolkit.analyse.lib.get_installed_use
+ defaults to gentoolkit.enalyze.lib.get_installed_use
@rtype dict. {cpv:['flag1', '-flag2',...]}
"""
if cpvs is None:
@@ -91,9 +91,9 @@ def cpv_all_diff_keywords(
keywords=portage.settings["ACCEPT_KEYWORDS"],
analyser = None
):
- """Analyse the installed pkgs 'keywords' for difference from ACCEPT_KEYWORDS
+ """Analyze the installed pkgs 'keywords' for difference from ACCEPT_KEYWORDS
- @param cpvs: optional list of [cat/pkg-ver,...] to analyse or
+ @param cpvs: optional list of [cat/pkg-ver,...] to analyze or
defaults to entire installed pkg db
@param system_keywords: list of the system keywords
@param keywords: user defined list of keywords to check and report on
@@ -182,11 +182,11 @@ class Rebuild(ModuleBase):
]
self.formatted_args = [
(" use",
- "causes the action to analyse the installed packages USE flags"),
+ "causes the action to analyze the installed packages USE flags"),
(" keywords",
- "causes the action to analyse the installed packages keywords"),
+ "causes the action to analyze the installed packages keywords"),
(" unmask",
- "causes the action to analyse the installed packages " + \
+ "causes the action to analyze the installed packages " + \
"current mask status")
]
self.short_opts = "hepsv"
@@ -269,7 +269,7 @@ class Rebuild(ModuleBase):
def rebuild_keywords(self):
print("Module action not yet available")
print()
"""This will scan the installed packages db and analyse the
keywords used for installation and produce a report on them.
"""
system_keywords = portage.settings["ACCEPT_KEYWORDS"].split()
@@ -357,7 +357,7 @@ class Rebuild(ModuleBase):
def main(input_args):
"""Common starting method by the analyse master
unless all modules are converted to this class method.
@param input_args: input args as supplied by equery master module.
@@ -269,7 +269,7 @@ class Rebuild(ModuleBase):
print("Module action not yet available")
print()
- """This will scan the installed packages db and analyse the
+ """This will scan the installed packages db and analyze the
keywords used for installation and produce a report on them.
"""
@@ -357,7 +357,7 @@ class Rebuild(ModuleBase):
def main(input_args):
- """Common starting method by the analyse master
+ """Common starting method by the analyze master
unless all modules are converted to this class method.